..  Copyright (C)  Brad Miller, David Ranum
    This work is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License. To view a copy of this license, visit http://creativecommons.org/licenses/by-nc-sa/4.0/.


Summary
-------

-  Computer science is the study of problem solving.

-  Computer science uses abstraction as a tool for representing both
   processes and data.

-  Abstract data types allow programmers to manage the complexity of a
   problem domain by hiding the details of the data.

-  Python is a powerful, yet easy-to-use, object-oriented language.

-  Lists, tuples, and strings are built in Python sequential
   collections.

-  Dictionaries and sets are nonsequential collections of data.

-  Classes allow programmers to implement abstract data types.

-  Programmers can override standard methods as well as create new
   methods.

-  Classes can be organized into hierarchies.

-  A class constructor should always invoke the constructor of its
   parent before continuing on with its own data and behavior.

